@@ -30,7 +30,10 @@
 #
 
 import base64
-import commands  # noqa
+try:
+    from subprocess import getoutput
+except ImportError:
+    from commands import getoutput  # noqa
 try:
     import json
 except ImportError:
@@ -48,11 +51,11 @@ DEFAULT_TIMEOUT = 30
 PluginError = dom0_pluginlib.PluginError
 
 
-class TimeoutError(StandardError):
+class TimeoutError(Exception):
     pass
 
 
-class RebootDetectedError(StandardError):
+class RebootDetectedError(Exception):
     pass
 
 
@@ -65,7 +68,7 @@ def version(self, arg_dict):
     xenstore.write_record(self, arg_dict)
     try:
         resp = _wait_for_agent(self, request_id, arg_dict, timeout)
-    except TimeoutError, e:  # noqa
+    except TimeoutError as e:  # noqa
         raise PluginError(e)
     return resp
 
@@ -87,7 +90,7 @@ def key_init(self, arg_dict):
     xenstore.write_record(self, arg_dict)
     try:
         resp = _wait_for_agent(self, request_id, arg_dict, timeout)
-    except TimeoutError, e:  # noqa
+    except TimeoutError as e:  # noqa
         raise PluginError(e)
     return resp
 
@@ -108,7 +111,7 @@ def password(self, arg_dict):
     xenstore.write_record(self, arg_dict)
     try:
         resp = _wait_for_agent(self, request_id, arg_dict, timeout)
-    except TimeoutError, e:  # noqa
+    except TimeoutError as e:  # noqa
         raise PluginError(e)
     return resp
 
@@ -124,7 +127,7 @@ def resetnetwork(self, arg_dict):
     xenstore.write_record(self, arg_dict)
     try:
         resp = _wait_for_agent(self, request_id, arg_dict, timeout)
-    except TimeoutError, e:  # noqa
+    except TimeoutError as e:  # noqa
         raise PluginError(e)
     return resp
 
@@ -170,7 +173,7 @@ def inject_file(self, arg_dict):
     xenstore.write_record(self, arg_dict)
     try:
         resp = _wait_for_agent(self, request_id, arg_dict, timeout)
-    except TimeoutError, e:  # noqa
+    except TimeoutError as e:  # noqa
         raise PluginError(e)
     return resp
 
@@ -190,7 +193,7 @@ def agent_update(self, arg_dict):
     xenstore.write_record(self, arg_dict)
     try:
         resp = _wait_for_agent(self, request_id, arg_dict, timeout)
-    except TimeoutError, e:  # noqa
+    except TimeoutError as e:  # noqa
         raise PluginError(e)
     return resp
 
@@ -198,7 +201,7 @@ def agent_update(self, arg_dict):
 def _get_agent_features(self, arg_dict):
     """Return an array of features that an agent supports."""
     timeout = int(arg_dict.pop('timeout', DEFAULT_TIMEOUT))
-    tmp_id = commands.getoutput("uuidgen")
+    tmp_id = getoutput("uuidgen")
     dct = {}
     dct.update(arg_dict)
     dct["value"] = json.dumps({"name": "features", "value": ""})
@@ -206,7 +209,7 @@ def _get_agent_features(self, arg_dict):
     xenstore.write_record(self, dct)
     try:
         resp = _wait_for_agent(self, tmp_id, dct, timeout)
-    except TimeoutError, e:  # noqa
+    except TimeoutError as e:  # noqa
         raise PluginError(e)
     response = json.loads(resp)
     if response['returncode'] != 0:
