@@ -37,10 +37,11 @@ except ImportError:
 
 import md5  # noqa
 import socket
-import urllib2
-from urlparse import urlparse
+
+from six.moves import urllib
 
 import dom0_pluginlib
+from six.moves.urllib.parse import urlparse
 import utils
 import XenAPI
 
@@ -73,12 +74,12 @@ def _download_tarball_and_verify(request, staging_path):
     socket.setdefaulttimeout(SOCKET_TIMEOUT_SECONDS)
 
     try:
-        response = urllib2.urlopen(request)
-    except urllib2.HTTPError, error:  # noqa
+        response = urllib.request.urlopen(request)
+    except urllib.error.HTTPError as error:  # noqa
         raise RetryableError(error)
-    except urllib2.URLError, error:  # noqa
+    except urllib.error.URLError as error:  # noqa
         raise RetryableError(error)
-    except httplib.HTTPException, error:  # noqa
+    except httplib.HTTPException as error:  # noqa
         # httplib.HTTPException and derivatives (BadStatusLine in particular)
         # don't have a useful __repr__ or __str__
         raise RetryableError('%s: %s' % (error.__class__.__name__, error))
@@ -96,7 +97,7 @@ def _download_tarball_and_verify(request, staging_path):
     try:
         try:
             utils.extract_tarball(response, staging_path, callback=update_md5)
-        except Exception, error:  # noqa
+        except Exception as error:  # noqa
             raise RetryableError(error)
     finally:
         bytes_read = callback_data['bytes_read']
@@ -149,7 +150,7 @@ def _download_tarball_by_url_v1(
         'image_id': image_id}
     logging.info("Downloading %s with glance v1 api" % url)
 
-    request = urllib2.Request(url, headers=extra_headers)
+    request = urllib.request.Request(url, headers=extra_headers)
     try:
         _download_tarball_and_verify(request, staging_path)
     except Exception:
@@ -166,7 +167,7 @@ def _download_tarball_by_url_v2(
         'image_id': image_id}
     logging.debug("Downloading %s with glance v2 api" % url)
 
-    request = urllib2.Request(url, headers=extra_headers)
+    request = urllib.request.Request(url, headers=extra_headers)
     try:
         _download_tarball_and_verify(request, staging_path)
     except Exception:
@@ -215,7 +216,7 @@ def _upload_tarball_by_url_v1(staging_path, image_id, glance_endpoint,
 
     try:
         conn = _create_connection(parts[0], parts[1])
-    except Exception, error:  # noqa
+    except Exception as error:  # noqa
         logging.exception('Failed to connect %(url)s' % {'url': url})
         raise RetryableError(error)
 
@@ -257,7 +258,7 @@ def _upload_tarball_by_url_v1(staging_path, image_id, glance_endpoint,
             for header, value in headers.items():
                 conn.putheader(header, value)
             conn.endheaders()
-        except Exception, error:  # noqa
+        except Exception as error:  # noqa
             logging.exception('Failed to upload %(url)s' % {'url': url})
             raise RetryableError(error)
 
@@ -268,7 +269,7 @@ def _upload_tarball_by_url_v1(staging_path, image_id, glance_endpoint,
             callback_data['bytes_written'] += chunk_len
             try:
                 conn.send("%x\r\n%s\r\n" % (chunk_len, chunk))
-            except Exception, error:  # noqa
+            except Exception as error:  # noqa
                 logging.exception('Failed to upload when sending chunks')
                 raise RetryableError(error)
 
@@ -360,7 +361,7 @@ def _upload_tarball_by_url_v2(staging_path, image_id, glance_endpoint,
 
     try:
         conn = _create_connection(parts[0], parts[1])
-    except Exception, error:  # noqa
+    except Exception as error:  # noqa
         raise RetryableError(error)
 
     try:
@@ -390,7 +391,7 @@ def _upload_tarball_by_url_v2(staging_path, image_id, glance_endpoint,
             for header, value in headers.items():
                 conn.putheader(header, value)
             conn.endheaders()
-        except Exception, error:  # noqa
+        except Exception as error:  # noqa
             logging.exception('Failed to upload %(url)s' % {'url': url})
             raise RetryableError(error)
 
@@ -401,7 +402,7 @@ def _upload_tarball_by_url_v2(staging_path, image_id, glance_endpoint,
             callback_data['bytes_written'] += chunk_len
             try:
                 conn.send("%x\r\n%s\r\n" % (chunk_len, chunk))
-            except Exception, error:  # noqa
+            except Exception as error:  # noqa
                 logging.exception('Failed to upload when sending chunks')
                 raise RetryableError(error)
 
@@ -512,7 +513,7 @@ def validate_image_status_before_upload_v1(conn, url, extra_headers):
         else:
             head_resp.read()
 
-    except Exception, error:  # noqa
+    except Exception as error:  # noqa
         logging.exception('Failed to HEAD the image %(image_id)s while '
                           'checking image status before attempting to '
                           'upload %(url)s' % {'image_id': image_id,
@@ -558,7 +559,7 @@ def validate_image_status_before_upload_v2(conn, url, extra_headers,
         # LP bug #1202785
         conn.request('GET', get_path, headers=extra_headers)
         get_resp = conn.getresponse()
-    except Exception, error:  # noqa
+    except Exception as error:  # noqa
         logging.exception('Failed to GET the image %(image_id)s while '
                           'checking image status before attempting to '
                           'upload %(url)s' % {'image_id': image_id,
